package MyC;
use 5.010;
use strict;
use warnings;

use MyA;

sub run { say 'MyC' }

1;

